==> lms-1.6.1+libs.tar.gz: lms/modules/nodescan.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodescan.php,v 1.20.2.1 2005/05/13 20:10:05 alec Exp $
 */

if($_GET['ownerid'] && $LMS->UserExists($_GET['ownerid']))
{
	$contractlist = $LMS->GetContractList();

	$SMARTY->assign('assignments', $LMS->GetUserAssignments($_GET['ownerid']));
	$SMARTY->assign('usergroups', $LMS->UsergroupGetForUser($_GET['ownerid']));
	$SMARTY->assign('otherusergroups', $LMS->GetGroupNamesWithoutUser($_GET['ownerid']));
	$SMARTY->assign('tariffs', $LMS->GetTariffs());
	$SMARTY->assign('userinfo', $LMS->GetUser($_GET['ownerid']));
	$SMARTY->assign('balancelist', $LMS->GetUserBalanceList($_GET['ownerid']));
	$SMARTY->assign('contractlist',$contractlist);
	$SMARTY->assign('contractcount',sizeof($contractlist));
}

$layout['pagetitle'] = trans('Nodes Scanning');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('nodes',$LMS->ScanNodes());
$SMARTY->display('nodescan.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/nodescan.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodescan.php,v 1.23 2005/09/18 08:30:02 alec Exp $
 */

if($_GET['ownerid'] && $LMS->CustomerExists($_GET['ownerid']))
{
	$SMARTY->assign('assignments', $LMS->GetCustomerAssignments($_GET['ownerid']));
	$SMARTY->assign('customergroups', $LMS->CustomergroupGetForCustomer($_GET['ownerid']));
	$SMARTY->assign('othercustomergroups', $LMS->GetGroupNamesWithoutCustomer($_GET['ownerid']));
	$SMARTY->assign('tariffs', $LMS->GetTariffs());
	$SMARTY->assign('customerinfo', $LMS->GetCustomer($_GET['ownerid']));
	$SMARTY->assign('balancelist', $LMS->GetCustomerBalanceList($_GET['ownerid']));
}

$layout['pagetitle'] = trans('Nodes Scanning');

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('nodes',$LMS->ScanNodes());
$SMARTY->display('nodescan.html');

?>
